Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(129)

Unified Diff: src/gpu/GrContextFactory.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrContext.cpp ('k') | src/gpu/GrContextFactory.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrContextFactory.h
diff --git a/src/gpu/GrContextFactory.h b/src/gpu/GrContextFactory.h
index 7fd4b77ce0bb2f7e4c6f31c8a4bce5ace05cc540..b557f98fea08ff036e30ca0aa2ee56623acd6cdb 100644
--- a/src/gpu/GrContextFactory.h
+++ b/src/gpu/GrContextFactory.h
@@ -116,7 +116,7 @@ public:
// Returns the GLContext of the given type. If it has not been created yet,
// NULL is returned instead.
SkGLContext* getGLContext(GLContextType type) {
for (int i = 0; i < fContexts.count(); ++i) {
if (fContexts[i].fType == type) {
@@ -124,7 +124,7 @@ public:
}
}
- return NULL;
+ return nullptr;
}
const GrContextOptions& getGlobalOptions() const { return fGlobalOptions; }
« no previous file with comments | « src/gpu/GrContext.cpp ('k') | src/gpu/GrContextFactory.cpp » ('j') | no next file with comments »
@@ -116,7 +116,7 @@ public:
// Returns the GLContext of the given type. If it has not been created yet,
- // NULL is returned instead.
+ // nullptr is returned instead.
SkGLContext* getGLContext(GLContextType type) {
for (int i = 0; i < fContexts.count(); ++i) {

Powered by Google App Engine
This is Rietveld 408576698